################ Culture coinfection analyses ################
#### 1. Data Sources and Preparing Data
#### 2. Test for nonrandom patterns of coinfection between ssDNA and dsDNA viruses
#### 3. Test whether hosts infected with prophages are likely to have other infections
#### 4. Sources explaining variation in the level of of culture coinfection

#Load libraries
library(ggplot2)
library(tidyr)
library(reshape2)
library(dplyr)
library(ggthemes)
library(gridExtra)

#### 1. Data Sources and Preparing Data   ####

#Analyzing data from Roux et al. 2015. Reference:
#Roux, S., Hallam, S. J., Woyke, T., & Sullivan, M. B. (2015). Viral dark matter and virus-host interactions resolved from publicly available microbial genomes. eLife, 4. doi:10.7554/eLife.08490

#Took Summary table of VirSorter data set sequences (figure-1—source-data-3.media-3.xls) and converted
#to CSV. Also "manually" modified using spreadsheet in the following ways:
#1) The comment row at the bottom of the was deleted
#2) The orange highlighted at the end of the spreadsheet were retained because:
# "the automatic annotation from NCBI did not display any viral-like gene, yet these sequences all 
# displayed statistical viral-like gene enrichment, and as such were maintained in the VirSorter curated data set"
# This CSV file is named 'summary_virsorter_sequences.csv'

#Import the data
summary_virsorter_sequences <- read.delim("data/unprocessed/summary_virsorter_sequences.csv")
View(summary_virsorter_sequences)

#This data frame 'summary_virsorter_sequences' contains the most data (prophage/ssDNA, number of genes), 
# but coinfection data calculated from this file may overestimate coinfection because of misassembled
# Caudovirales genomes. Simon Roux provided 3 files via email on 11-25-2015 (these are untouched in data/unprocesed/)
# that include only the curated (most likely) coinfections beacuse of potential Caudovirales misassembly
# These files were converted to CSV using the script 'code_bash_process_lst_files'

#I created a fourth file that merges the "List_of_coinfection_by_host-outside-Caudovirales.csv" and 
# "List_of_coinfection_by_host-multiple-Caudovirales.csv" by "manually" pasted together both files in 
# spreadsheet program

curated_coinfections <- read.delim("data/curated_coinfections.csv", header=FALSE)
View(curated_coinfections)

#Name columns.
colnames(curated_coinfections) <- c("Host", "Seq.Id", "Genes", "Affiliation", "TerL")

#To get both data sets together, I merged 'summary_virsorter_sequences' and 'List_detection_by_host',
# sorted by Seq.ID 
# An inner join with 'curated_coinfections' was not possible, because some of the Seq.ID's in the *.lst 
# files do not exactly match the 'summary_virsorter_sequences'

#Sort the file to align data frames
sorted <- summary_virsorter_sequences[order(summary_virsorter_sequences$Seq.Id),]
View(sorted)

#Import the second file that aligns with 'summary_virsorter_sequences' but has slightly different Seq.ID names
List_detection_by_host <- read.delim("data/unprocessed/List_detection_by_host.csv", header=FALSE)
View(List_detection_by_host)

#Name columns.
colnames(List_detection_by_host) <- c("Host", "Seq_ID", "Genes", "Affiliation")

#Now sort on sequence IDs
sorted_list_detection <- List_detection_by_host[order(List_detection_by_host$Seq_ID),]
View(sorted_list_detection)

#Check if gene numbers are the same, this is another common field between data frames that should match
# in both data frames
#Need to change the multiple value field to extract the gene number
sorted_genes <- separate(sorted, Gene..Total...Viral...PFAM...Unknown.., c("Gene", "Viral", "PFAM", "Unknown"), sep=";")
true_false_vector <- sorted_list_detection$Genes == sorted_genes$Gene
nrow(sorted_list_detection)
nrow(sorted_genes)
length(true_false_vector[true_false_vector == FALSE])
#[1] 44
#NOTE: Gene numbers in some viral sequences do not match. In some cases the SeqID's are transposed 
# (in Seq.ID _part1 and _part2 for example), but some are different altogether.
#Hosts, however do match the order of SeqID's should not change results

big_data_frame <- cbind(sorted_genes, sorted_list_detection)
non_matching_genes <- subset(big_data_frame, Gene != Genes)
View(data.frame(non_matching_genes$Gene, non_matching_genes$Genes, non_matching_genes$Seq_ID, non_matching_genes$Seq.Id, non_matching_genes$Host, non_matching_genes$Host.species.strain))

#Check if hosts are the same
true_false_vector <- sorted_list_detection$Host == sorted_genes$Host.species.strain
length(true_false_vector[true_false_vector == FALSE])
#[1] 0 #They are.

#Need to break up the Affilitation of virus column in big data frame so I can get info on dsDNA vs ssDNA
big_data_frame <- separate(big_data_frame, Affiliation.of.viral.sequence..LCA.on.best.BLAST.hits., c("Virus", "Nucleic", "Order", "Family", "Genus", "Species"), sep = ";", extra="drop")

#Now I can do an inner join with the curated coinfections. Let's check columns first
View(big_data_frame)
View(curated_coinfections)

#First let's make sure the "by" columns match
colnames(curated_coinfections) <- c("Host", "Seq_ID", "Genes", "Affiliation", "TerL")

curated_coinfections_all <- inner_join(curated_coinfections, big_data_frame, by="Seq_ID")

View(curated_coinfections_all)
nrow(curated_coinfections_all)
#8770, so looks good

#Checking numbers of generated data frames
#Is there a difference in the global statistics?
curated_coinfections_all_table <- as.data.frame(table(curated_coinfections_all$Host.x))
nrow(curated_coinfections_all_table)
#[1] 2445
#So about 2947-2445 = 502 hosts were putative coinfections in the 'summary_virsorter_sequences',
# but were thrown out due to being potentially mis-assembled Caudovirales single infections
 
#Checking numbers of generated data frames
nrow(as.data.frame(table(big_data_frame$Host.species.strain)))
#[1] 5492
#Proportion of host cultures coinfected
nrow(subset(curated_coinfections_all_table, Freq > 1)) / nrow(as.data.frame(table(big_data_frame$Host.species.strain)))
#[1] 0.445193
# Compared to 2947/5492 = 0.5365987 from 'summary_virsorter_sequences'
#Well these numbers match what Roux et al. 2015 report so that's good

###### Need to add metadata to test factors affecting culture coinfection (Section 4 of code)
## This involves two steps. Preparing the Roux metadata and then preparing the GOLD metadata for importing
# These steps are detailed in 'culture_coinfection_metadata_gold_code.R'
culture_coinfection_gold_metadata <- read.csv("data/culture_coinfection_gold_metadata.csv")
View(culture_coinfection_gold_metadata)


#### 2. Test for nonrandom patterns of coinfection between ssDNA and dsDNA viruses ####

#How many of each nucleic acid type (dsDNA or ssDNA) is coinfecting each host?
nucleic_coinfection <- as.data.frame(table(curated_coinfections_all$Nucleic, curated_coinfections$Host))
View(nucleic_coinfection)

#Adjust names
colnames(nucleic_coinfection) <- c("Nucleic", "Host", "Viruses")

#Now have to cast to get tidy data set where each row is 1 host 
nucleic_coinfection_cast <- dcast(nucleic_coinfection, Host~Nucleic)
View(nucleic_coinfection_cast)
#Looks good!

#How many dsDNA vs ssDNA vs unclasified sequences do we have?
#Use colsums, bUT need to subset out the first column (host), because it's non-numeric 
colSums(nucleic_coinfection_cast[2:5])

#Adjust names
colnames(nucleic_coinfection_cast) <- c("Host", "dsDNA", "ssDNA", "unclassified", "unclassified_phage")

#Create a total column to make things easier
nucleic_coinfection_cast <- mutate(nucleic_coinfection_cast, total = dsDNA + ssDNA + unclassified + unclassified_phage)
head(nucleic_coinfection_cast)

View(subset(nucleic_coinfection_cast, ssDNA  > 0))

#Coinfections with at least one ssDNA virus
nrow(subset(nucleic_coinfection_cast, ssDNA  > 0))
#[1] 331

#Coinfections between ssDNA and unclassified
nrow(subset(nucleic_coinfection_cast, ssDNA > 0 & unclassified > 0 & dsDNA == 0))
#[1] 7

#Coinfections between ssDNA and unclassified phage
nrow(subset(nucleic_coinfection_cast, ssDNA > 0 & unclassified_phage > 0 & dsDNA == 0))
#[1] 1

#Coinfections only between ssDNA
nrow(subset(nucleic_coinfection_cast, ssDNA > 0 & dsDNA == 0 & unclassified == 0 & unclassified_phage == 0))
#[1] 97

#Coinfections with at least one ssDNA virus and at least one dsDNA virus
nrow(subset(nucleic_coinfection_cast, ssDNA  > 0 & dsDNA > 0))
#[1] 226

#Quick check
7+1+97+226
#[1] 331

#Test: Do ssDNA-mixed coinfections happen more often than ssDNA only coinfections coinfections?
# Total ssDNA-only coinfections = 97, Total ssDNA mixed coinfections 226+7+1 = 234
binom.test(234, 331, p = 0.5, alternative = "two.sided", conf.level = 0.95)
#Exact binomial test
#data:  234 and 331
#number of successes = 234, number of trials = 331, p-value = 3.314e-14
#alternative hypothesis: true probability of success is not equal to 0.5
#95 percent confidence interval:
#  0.6547021 0.7554472
#sample estimates:
#  probability of success 
#0.7069486

#Yes they do

#Test: Are ssDNA-dsDNA coinfections happening more often than other ssDNA coinfections?
# Total ssDNA-dsDNA coinfections = 226
binom.test(226, 331, p = 0.5, alternative = "two.sided", conf.level = 0.95)
#Exact binomial test
#data:  226 and 331
#number of successes = 226, number of trials = 331, p-value = 2.559e-11
#alternative hypothesis: true probability of success is not equal to 0.5
#95 percent confidence interval:
#  0.6296595 0.7325919
#sample estimates:
#  probability of success 
#0.6827795


#In response to reviewer comments, looking at dsDNA coinfections as well

#Coinfections with at least one dsDNA virus
nrow(subset(nucleic_coinfection_cast, dsDNA  > 0))
#[1] 2328

#Coinfections between dsDNA and unclassified
nrow(subset(nucleic_coinfection_cast, dsDNA > 0 & unclassified > 0))
#[1] 158

#Coinfections between dsDNA and unclassified phage
nrow(subset(nucleic_coinfection_cast, dsDNA > 0 & unclassified_phage > 0))
#[1] 69

#Coinfections only between dsDNA
nrow(subset(nucleic_coinfection_cast, dsDNA > 0 & ssDNA == 0 & unclassified == 0 & unclassified_phage == 0))
#[1] 1898

#Coinfections with at least one ssDNA virus and at least one dsDNA virus
nrow(subset(nucleic_coinfection_cast, ssDNA  > 0 & dsDNA > 0))
#[1] 226

#Test: Do dsDNA-mixed coinfections happen more often than dsDNA-only coinfections?
# Total dsDNA-only coinfections = 1898, Total dsDNA mixed coinfections 158+69+226 = 453
binom.test(453, 2345, p = 0.5, alternative = "two.sided", conf.level = 0.95)
#Exact binomial test
#data:  453 and 2345
#number of successes = 453, number of trials = 2345, p-value < 2.2e-16
#alternative hypothesis: true probability of success is not equal to 0.5
#95 percent confidence interval:
#  0.1773759 0.2097482
#sample estimates:
#  probability of success 
#0.193177

#No. dsDNA-only coinfections more likely to happen than dsDNA mixed coinfections

#Test: Is the proportion of ssDNA-mixed/total-ssDNA coinfections higher than the proportion
# of dsDNA-mixed/dsDNA-total coinfections?
#dsDNA-mixed coinfections/all dsDNA coinfections = 453/2345
#ssDNA-mixed coinfections/all ssDNA coinfections = 234/331
prop.test(c(453, 234), c(2345, 331), alternative = "two.sided", conf.level = 0.95)
#2-sample test for equality of proportions with continuity correction
#data:  c(453, 234) out of c(2345, 331)
#X-squared = 398.5534, df = 1, p-value < 2.2e-16
#alternative hypothesis: two.sided
#95 percent confidence interval:
#  -0.5670676 -0.4604758
#sample estimates:
#  prop 1    prop 2 
#0.1931770 0.7069486 

#Yes. Higher and highly unlikely to arise by chance.

#The concern would be that detection of ssDNA viruses is driving the pattern.
#Would need to look at ssDNA detections in the overall viral infection data set and compare to coinfections

#Get stats for the overall infection data set
#How many of each nucleic acid type (dsDNA or ssDNA) is infecting each host?
nucleic_infection <- as.data.frame(table(big_data_frame$Nucleic, big_data_frame$Host))
head(nucleic_infection)

#Adjust names
colnames(nucleic_infection) <- c("Nucleic", "Host", "Viruses")

#Now have to cast to get tidy data set where each row is 1 host 
nucleic_infection_cast <- dcast(nucleic_infection, Host~Nucleic)
head(nucleic_infection_cast)
#Looks good!

#How many dsDNA vs ssDNA vs unclasified sequences do we have in infections (overall data set)?
#Use colsums, bUT need to subset out the first column (host), because it's non-numeric 
colSums(nucleic_infection_cast[2:5])

#Adjust names
colnames(nucleic_infection_cast) <- c("Host", "dsDNA", "ssDNA", "unclassified", "unclassified_phage")

#Create a total column to make things easier
nucleic_infection_cast <- mutate(nucleic_infection_cast, total = dsDNA + ssDNA + unclassified + unclassified_phage)
head(nucleic_infection_cast)

#Totals for infections
colSums(nucleic_infection_cast[2:5])
#dsDNA              ssDNA       unclassified unclassified_phage 
#11305                852                240                 93 

#Totals for COinfections
colSums(nucleic_coinfection_cast[2:5])
#dsDNA              ssDNA       unclassified unclassified_phage 
#7942                543                204                 80

#Proportion of ssDNA viruses detected in infections
#ssDNA/total viruses; total viruses = 11305 + 852 + 240 + 93 = 12490
852/12490
#[1] 0.06821457

#Proportion of ssDNA viruses detected in co-infections
#ssDNA/total coinfecting viruses; total coinfecting viruses = 7942 + 543 + 204 + 80 = 8769
543/8769
#[1] 0.06192268

#Are the proportion of ssDNA viruses detected in coinfections different from those detected in entire infection
# data set?
prop.test(c(852, 543), c(12490, 8769), alternative = "two.sided", conf.level = 0.95)
#2-sample test for equality of proportions with continuity correction
#data:  c(852, 543) out of c(12490, 8769)
#X-squared = 3.2246, df = 1, p-value = 0.07254
#alternative hypothesis: two.sided
#95 percent confidence interval:
#  -0.0005130659  0.0130968448
#sample estimates:
#  prop 1     prop 2 
#0.06821457 0.06192268 

#Difference in proportion of ssDNA viruses detected in coinfection compared to ssDNA viruses detected in entire 
# infection data set is 0.63% and not statistically different than zero

#Also in response to reviewer comments that there are ssDNA viruses other than those in the Inoviridae 
# that may not have prolonged chronic infections, and that those would not be in the data set, 
# I'm examining how many of the ssDNA viruses in the culture coinfection data set are from 
# the different ssDNA virus families

#Take an initial look in the overall data set
subset(big_data_frame, Nucleic == "ssDNA viruses", select = c("Virus", "Order", "Family", "Genus", "Species"))
#Looks like a lot of Inoviridae!

#What is the total number of ssDNA virus detections in the entire data set
nrow(subset(big_data_frame, Nucleic == "ssDNA viruses", select = c("Virus", "Order", "Family", "Genus", "Species")))
#[1] 852
# Looks like there is only Inoviridae, Microviridae, and unkown

#Totals
table(subset(big_data_frame, Nucleic == "ssDNA viruses", select = "Family"))
#Inoviridae Microviridae      unknown 
#775            6           71
(c(775, 6, 71)/(775+6+71))*100
#90.9624413     0.7042254   8.3333333

#Ha! Innoviridae are the majority (90.96) of the data set. Thanks Reviewer #2! #sciencejudo

#Now let's take it a step further and see if the Inoviridae viruses were preferentially 
# involved in ssDNA-dsDNA coinfections. Although there are so few of the others...

#Make a data frame with virus family information for coinfections
nucleic_coinfection_family <- as.data.frame(table(curated_coinfections_all$Family, curated_coinfections_all$Host.y))
head(nucleic_coinfection_family)

#Adjust names
colnames(nucleic_coinfection_family) <- c("Family", "Host", "Viruses")

#Now have to cast to get tidy data set where each row is 1 host 
nucleic_coinfection_family_cast <- dcast(nucleic_coinfection_family, Host~Family)
head(nucleic_coinfection_family_cast)
#Looks good!

#Now join data frames that have information on virus nucleic acid composition and family membership  
nucleic_coinfection_family_cast_join <- left_join(nucleic_coinfection_cast, nucleic_coinfection_family_cast, by="Host")
head(nucleic_coinfection_family_cast_join)

#Quick quality control check:
nucleic_coinfection_family_cast_join <- mutate(nucleic_coinfection_family_cast_join, total_fam = Var.2+Corticoviridae+Fuselloviridae+Inoviridae+Microviridae+Myoviridae+Podoviridae+Siphoviridae+Tectiviridae+unclassified.y+unknown)
head(nucleic_coinfection_family_cast_join)

#Do the totals add up?
nucleic_coinfection_family_cast_join$total == nucleic_coinfection_family_cast_join$total_fam
#yes

#Total number of coinfected hosts with at least 1 ssDNA virus detection. Should be same as above
nrow(subset(nucleic_coinfection_family_cast_join, total > 0 & ssDNA > 0))
#[1] 331

#Now what are subtotals for ssDNA virus families 
nrow(subset(nucleic_coinfection_family_cast_join, total > 0 & ssDNA  > 0 & Inoviridae > 0))
#[1] 307
nrow(subset(nucleic_coinfection_family_cast_join, total > 0 & ssDNA > 0 & Microviridae > 0))
#[1] 1
nrow(subset(nucleic_coinfection_family_cast_join, total > 0 & ssDNA  > 0 & unknown > 0))
#[1] 24

#Toatal dsDNA-ssDNA coinfections
nrow(subset(nucleic_coinfection_family_cast_join, ssDNA  > 0 & dsDNA > 0))
#[1] 226 ##Same as before

#ssDNA viral families involved in dsDNA-ssDNA coinfections
nrow(subset(nucleic_coinfection_family_cast_join, ssDNA  > 0 & dsDNA > 0 & Inoviridae > 0))
#[1] 217
nrow(subset(nucleic_coinfection_family_cast_join, ssDNA  > 0 & dsDNA > 0 & Microviridae > 0))
#[1] 1
nrow(subset(nucleic_coinfection_family_cast_join, ssDNA  > 0 & dsDNA > 0 & unknown > 0))
#[1] 8

#Percent of Inoviridae ssDNA-dsDNA coinfected hosts
217/226
#[1] 0.960177

#The Question is: are Innoviridae overrepresented in coinfections relative to single infections

#Are Inoviridae overrepresented in ssDNA-dsDNA coinfections relative to ssDNA single infections or
# ssDNA-only coinfections?

#Make a data frame with information on Family for the overall infection data set
family_infection <- as.data.frame(table(big_data_frame$Family, big_data_frame$Host))
head(family_infection)

#Adjust names
colnames(family_infection) <- c("Family", "Host", "Viruses")

#Now have to cast to get tidy data set where each row is 1 host 
family_infection <- dcast(family_infection, Host~Family)
head(family_infection)
#Looks good!

#Now join data frames that have information on virus nucleic acid composition and family membership  
family_infection_join <- left_join(nucleic_infection_cast, family_infection, by="Host")
head(family_infection_join)

#Innoviridae in single infections
nrow(subset(family_infection_join, total == 1 & Inoviridae == 1 & ssDNA == 1))
#[1] 280
nrow(subset(family_infection_join, total == 1 & unknown == 1 & ssDNA == 1))
#[1] 24
nrow(subset(family_infection_join, total == 1 & Microviridae == 1 & ssDNA == 1))
#[1] 5
#Total
nrow(subset(family_infection_join, total == 1 & ssDNA == 1))
#[1] 309 should sum all above 

#Proportion of Inoviridae in single infections
280/309
#[1] 0.9061489 ## As an aside very close to Inoviridae prevalence in entire data set 0.9096244

#Total ssDNA-only CO-infections
nrow(subset(nucleic_coinfection_family_cast_join, ssDNA  > 0 & dsDNA == 0))
#[1] 105
#ssDNA coinfections by Inoviridae 
nrow(subset(nucleic_coinfection_family_cast_join, ssDNA  > 0 & dsDNA == 0 & Inoviridae > 0))
#[1] 90

#Proprtion of ssDNA-only co-infections with Inoviridae
90/105
#[1] 0.8571429

#Recalling from above, the proportion of Inoviridae in dsDNA-ssDNA coinfections is:
#ssDNA viral families involved in dsDNA-ssDNA coinfections
nrow(subset(nucleic_coinfection_family_cast_join, ssDNA  > 0 & dsDNA > 0 & Inoviridae > 0))
#[1] 217
nrow(subset(nucleic_coinfection_family_cast_join, ssDNA  > 0 & dsDNA > 0 & Microviridae > 0))
#[1] 1
nrow(subset(nucleic_coinfection_family_cast_join, ssDNA  > 0 & dsDNA > 0 & unknown > 0))
#[1] 8

#Percent of Inoviridae ssDNA-dsDNA coinfected hosts
217/226
#[1] 0.960177

#Is the difference in these proportions statistically different from zero?
prop.test(c(90, 280, 217), c(105, 309, 226), alternative = "two.sided", conf.level = 0.95)
#3-sample test for equality of proportions without continuity correction
#data:  c(90, 280, 217) out of c(105, 309, 226)
#X-squared = 10.9787, df = 2, p-value = 0.00413
#alternative hypothesis: two.sided
#sample estimates:
#  prop 1    prop 2    prop 3 
#0.8571429 0.9061489 0.9601770

#Yes. So, we have a 5.40% and 10.30% increase in the proportion of hosts with Inovirdae in dsDNA-ssDNA 
# coinfections relatve to ssDNA-only single infections and ssDNA-only CO-infections

#No need to make too much hay out of this because Inoviridae already so prevalent in overall data set
# but worth mentioning it's consistent with the idea that Inoviridae are associated with coinfection
# and dsDNA-ssDNA coinfection specifically

##Now code for Figure 5
#First need to add a compsition of co-infection column. Make a function to apply dplyr:mutate_each()

#Group all ssDNA-only coinfections
ssDNA_only <- subset(nucleic_coinfection_cast, ssDNA > 0 & dsDNA == 0 & unclassified == 0 & unclassified_phage == 0)
composition <- NULL
composition <- rep("ssDNA-only", times = nrow(ssDNA_only))
View(cbind(ssDNA_only, composition)) #Just checking
ssDNA_only <- cbind(ssDNA_only, composition)

#Group all coinfections with ssDNA and at least one dsDNA virus
ssDNA_ds_DNA <-subset(nucleic_coinfection_cast, ssDNA  > 0 & dsDNA > 0)
composition <- NULL
composition <- rep("ssDNA-dsDNA", times = nrow(ssDNA_ds_DNA))
View(cbind(ssDNA_ds_DNA, composition)) #Just checking
ssDNA_ds_DNA <- cbind(ssDNA_ds_DNA, composition)

#Group all coinfections with ssDNA and unclassified viruses
#Making sure subset works, note parentheses to group unlcassified categories
View(subset(nucleic_coinfection_cast, ssDNA  > 0 & dsDNA == 0 & (unclassified > 0 | unclassified_phage > 0)))
ssDNA_unclass <- subset(nucleic_coinfection_cast, ssDNA  > 0 & dsDNA == 0 & (unclassified > 0 | unclassified_phage > 0))
composition <- NULL
composition <- rep("ssDNA + unclassified", times = nrow(ssDNA_unclass))
View(cbind(ssDNA_unclass, composition)) #Just checking
ssDNA_unclass <- cbind(ssDNA_unclass, composition)

#Bring them all together
View(rbind(ssDNA_ds_DNA, ssDNA_only, ssDNA_unclass))
ssDNA_coinfection_types <- rbind(ssDNA_ds_DNA, ssDNA_only, ssDNA_unclass)
#Check we have them all
nrow(subset(nucleic_coinfection_cast, ssDNA  > 0)) == nrow(ssDNA_coinfection_types)
#[1] TRUE #yes

qplot(ssDNA_coinfection_types$composition)

#Figure 5A
#requires ggthemes library
figure5a <- ggplot(ssDNA_coinfection_types, aes(x = composition, fill = composition)) + geom_histogram(col = "black") +
  coord_flip() +
  xlab("Composition of Coinfections") +
  ylab("Number of Hosts") +
  theme_few() + scale_colour_few() +
  theme(legend.position="none") +
  #theme(legend.position = c(0.8, 0.8)) +
  scale_fill_manual(values = c("lightblue","grey", "lightblue"))

#See the figure 
figure5a

#Setting up for Figure 5B with information on dsDNA coinfection, compared to ssDNA coinfection 


#Group all dsDNA-only coinfections
dsDNA_only <- subset(nucleic_coinfection_cast, dsDNA > 0 & ssDNA == 0 & unclassified == 0 & unclassified_phage == 0)
composition <- NULL
composition <- rep("dsDNA-only", times = nrow(dsDNA_only))
View(cbind(dsDNA_only, composition)) #Just checking
dsDNA_only <- cbind(dsDNA_only, composition)

#Group all dsDNA-mixed coinfections
dsDNA_mixed <- rbind(subset(nucleic_coinfection_cast, dsDNA > 0 & unclassified > 0), 
                     subset(nucleic_coinfection_cast, dsDNA > 0 & unclassified_phage > 0),
                     subset(nucleic_coinfection_cast, dsDNA > 0 & ssDNA > 0))
composition <- NULL
composition <- rep("dsDNA-mixed", times = nrow(dsDNA_mixed))
dsDNA_mixed <- cbind(dsDNA_mixed, composition)

#Bring them together
View(rbind(dsDNA_mixed, dsDNA_only))
dsDNA_coinfection_types <- rbind(dsDNA_mixed, dsDNA_only)
panel <- NULL
panel <- rep("dsDNA", times = nrow(dsDNA_coinfection_types))
dsDNA_coinfection_types <- cbind(dsDNA_coinfection_types, panel)

qplot(dsDNA_coinfection_types$composition)

#Changing ssDNA data frame from Fig 5A to plot Fig 5B
head(ssDNA_coinfection_types)
ssDNA_coinfection_types2 <- ssDNA_coinfection_types
levels(ssDNA_coinfection_types2$composition) <- c("ssDNA-dsDNA", "ssDNA-only", "ssDNA + unclassified", "ssDNA-mixed")
ssDNA_coinfection_types2$composition[ssDNA_coinfection_types2$composition == "ssDNA + unclassified"] <- "ssDNA-mixed"
ssDNA_coinfection_types2$composition[ssDNA_coinfection_types2$composition == "ssDNA-dsDNA"] <- "ssDNA-mixed"
ssDNA_coinfection_types2$composition <- factor(ssDNA_coinfection_types2$composition)
levels(ssDNA_coinfection_types2$composition)
panel <- NULL
panel <- rep("ssDNA", times = nrow(ssDNA_coinfection_types2))
ssDNA_coinfection_types2 <- cbind(ssDNA_coinfection_types2, panel)

qplot(ssDNA_coinfection_types2$composition)

#Bring all together
View(rbind(dsDNA_coinfection_types, ssDNA_coinfection_types2))
all_nucleic_coinfection_types <- rbind(dsDNA_coinfection_types, ssDNA_coinfection_types2)

figure5b <- ggplot(all_nucleic_coinfection_types, aes(x = composition, fill = composition)) + geom_histogram(col = "black") +
  coord_flip() +
  xlab("Composition of Coinfections") +
  ylab("Number of Hosts") +
  theme_few() + scale_colour_few() +
  theme(legend.position="none") +
  #theme(legend.position = c(0.8, 0.8)) +
  scale_fill_manual(values = c("indianred4", "indianred4", "grey", "lightblue"))

#See graph
figure5b

#Put both graphs in one 
grid.arrange(figure5a, figure5b, nrow = 1)

#### 3. Test whether hosts infected with prophages are likely to have other infections ####

# From Roux et al. 2015, referencing the entire data set:
# "Among these, 7266 sequences were entirely viral (thus potentially represent lytic, chronic, or 
# extrachromosomal lysogenic infections assembled in draft genomes), and 5232 were prophages 
# (viral-like regions detected within a cellular genome fragment).

#Here I will be analyzing the composition of co-infections primarily

#Overall, what is the distribution of prophages and extrachromosomal infections in co-infected hosts?
ggplot(data=curated_coinfections_all, aes(x=Sequence.type)) + geom_histogram()

#Make a cross tabulation of the infection modes (i.e extrachromosomal or integrated prophage) in coinfected hosts  
coinfection_infection_mode <- as.data.frame(table(curated_coinfections_all$Sequence.type, curated_coinfections_all$Host.x))
View(coinfection_infection_mode)

#Adjust names
colnames(coinfection_infection_mode) <- c("Mode", "Host", "Viruses")

## Cast data set to manipulate data more easily
coinfection_infection_mode_cast <- dcast(coinfection_infection_mode, Host~Mode)
head(coinfection_infection_mode_cast)

#Add a total column, but should not be needed becuase all are co-infections
coinfection_infection_mode_cast <- mutate(coinfection_infection_mode_cast, total = extrachromosomal + prophage)

#Let's start some counts
nrow(coinfection_infection_mode_cast)
#[1] 2445 #This matches Roux et al.'s reported number of coinfected hosts
nrow(subset(coinfection_infection_mode_cast, total == 1))
#[1] 0 #as expected

### 3a. Calculating how many viruses participate in extrachromosomal-only and prophage-only culture coinfections ###

#Mean coinfection level of coinfected hosts by extrachromosomal viruses
mean(coinfection_infection_mode_cast$extrachromosomal[coinfection_infection_mode_cast$extrachromosomal > 1])
#[1] 3.351429
#Slightly lower only than before, using non-curated coinfection data set ([1] 3.172717)

#Mean coinfection level of coinfected hosts ONLY by extrachromosomal viruses
mean(coinfection_infection_mode_cast$extrachromosomal[coinfection_infection_mode_cast$prophage == 0 & coinfection_infection_mode_cast$extrachromosomal > 0])
#[1] 3.251852 Higher than before when analyzing non-curated coinfections ([1] 2.996795)

#Histogram of Infections in hosts coinfected only by extrachromosomal viruses
ggplot(subset(coinfection_infection_mode_cast, prophage == 0 & extrachromosomal > 0), aes(extrachromosomal) ) + 
  geom_histogram(breaks=seq(0, 20, by=1), col="red") + 
  scale_x_continuous(breaks=seq(0, 20, by=1)) +
  theme(axis.title.y = element_text(angle=90, face="plain", size = rel(1.4)), axis.title.x = element_text(face="plain", size = rel(1.4)), panel.background = element_rect(fill = 'white'), plot.background = element_rect(fill = 'grey90')) +
  labs(x="Infections in hosts coinfected only by extrachromosomal viruses", y="Frequency")

#Mean coinfection level of coinfected hosts ONLY by prophages
mean(coinfection_infection_mode_cast$prophage[coinfection_infection_mode_cast$prophage > 0 & coinfection_infection_mode_cast$extrachromosomal == 0])
#[1] 2.543403 Slightly higher than before when analyzing non-curated coinfections (#[1] 2.51129)

#Histogram of Infections in hosts coinfected only by integrated prophages
ggplot(subset(coinfection_infection_mode_cast, prophage > 0 & extrachromosomal == 0 ), aes(prophage)) + 
  geom_histogram(breaks=seq(0, 20, by=1), col="red") + 
  scale_x_continuous(breaks=seq(0, 20, by=1)) +
  theme(axis.title.y = element_text(angle=90, face="plain", size = rel(1.4)), axis.title.x = element_text(face="plain", size = rel(1.4)), panel.background = element_rect(fill = 'white'), plot.background = element_rect(fill = 'grey90')) +
  labs(x="Infections in hosts coinfected only by integrated prophages", y="Frequency")

#Is the mean culture-level coinfection level different for coinfections only by prophages compared to only by extrachromosomal viruses
prophage_only <- coinfection_infection_mode_cast$prophage[coinfection_infection_mode_cast$prophage > 0 & coinfection_infection_mode_cast$extrachromosomal == 0]
extrachromosomal_only <- coinfection_infection_mode_cast$extrachromosomal[coinfection_infection_mode_cast$prophage == 0 & coinfection_infection_mode_cast$extrachromosomal > 0]

#Performing non-parametric rank test because data not normally distributed
wilcox.test(prophage_only, extrachromosomal_only, conf.int = T)

#Wilcoxon rank sum test with continuity correction
#data:  prophage_only and extrachromosomal_only
#W = 125398.5, p-value < 2.2e-16
#alternative hypothesis: true location shift is not equal to 0
#95 percent confidence interval:
#  -9.999081e-01 -4.054968e-05
#sample estimates:
#  difference in location 
#-0.999954 

#Yes it is. More coinfection in Extrachromosomal infections
mean(prophage_only)
#[1] 2.543403
sd(prophage_only)
#[1] 1.022286
length(prophage_only)
#[1] 576 #sample size

mean(extrachromosomal_only)
#[1] 3.251852
sd(extrachromosomal_only)
#[1] 1.341633
length(extrachromosomal_only)
#[1] 675 #sample size

#Figure 4B - Average number of viruses in extrachromosomal-only and prophage-only co-infections

#Prepare data to be plotted
#Checking
head(coinfection_infection_mode_cast)

#Group and label host cultures that are coinfected by a) prophage only b) mixed prophage/extrachromosomal and 
# c) extrachromosomal only. Note nested ifelse statement. 
coinfection_infection_mode_cast$composition <- ifelse(coinfection_infection_mode_cast$extrachromosomal == 0 & coinfection_infection_mode_cast$prophage > 0, "Prophage Only", 
                                                     ifelse(coinfection_infection_mode_cast$extrachromosomal > 0 & coinfection_infection_mode_cast$prophage > 0, "Mixed", "Extrachromosomal Only"))

#Check that all is working as intended
length(coinfection_infection_mode_cast$composition[coinfection_infection_mode_cast$composition == "Prophage Only"])
#[1] 576 #looks good
#Check that all is working as intended
length(coinfection_infection_mode_cast$composition[coinfection_infection_mode_cast$composition == "Extrachromosomal Only"])
#[1] 675 #checks out
length(coinfection_infection_mode_cast$composition[coinfection_infection_mode_cast$composition == "Mixed"])
#[1] 1194

#Plot Figure 4C. Number of viruses in prophage-only vs extrachromosomal-only coinfections
fig4C <- ggplot(subset(coinfection_infection_mode_cast, composition != "Mixed"), aes(x = composition, y = total)) +
  geom_jitter(position = position_jitter(width = 0.2), alpha = 1/4) +
  geom_errorbar(stat = "hline", yintercept = "mean", width=0.6, size=1, aes(ymax=..y..,ymin=..y..)) +
  ylab("Number of viruses in each host culture") +
  xlab("") +
  scale_y_continuous(breaks=seq(0, 12, by=1)) +
  theme(legend.position="none")

#View Plot
fig4C

### 3b. Calculating proportion of host cultures coinfected by prophages and extrachromosomal viruses ###

#Number of Hosts in virsorter data set
nrow(as.data.frame(table(big_data_frame$Host.species.strain)))
#[1] 5492

#Number of hosts coinfected (after quality control using TerL genes)
nrow(coinfection_infection_mode_cast)
#[1] 2445

#Number of hosts coinfected exclusively by extrachromosomal phage 
nrow(subset(coinfection_infection_mode_cast, extrachromosomal > 0 & prophage == 0))
#[1] 675

#Number of hosts coinfected exclusively by prophages 
nrow(subset(coinfection_infection_mode_cast, extrachromosomal == 0 & prophage > 0))
#[1] 576

#Number of hosts coinfected by both prophages and extrachromosomal viruses 
nrow(subset(coinfection_infection_mode_cast, extrachromosomal > 0 & prophage > 0))
#[1] 1194

#Quick verify
675 + 576 + 1194
#[1] 2445 #looks good

##What are those mixed infections (i.e. extra/pro) composed of?

#Multiple extrachromosomal and multiple prophages
nrow(subset(coinfection_infection_mode_cast, extrachromosomal > 1 & prophage > 1))
#[1] 377

#Multiple extrachromosomal and one prophage
nrow(subset(coinfection_infection_mode_cast, extrachromosomal > 1 & prophage == 1))
#[1] 348

#One extrachromosomal and multiple prophage
nrow(subset(coinfection_infection_mode_cast, extrachromosomal == 1 & prophage > 1))
#[1] 228

#One extrachromosomal and one prophage
nrow(subset(coinfection_infection_mode_cast, extrachromosomal == 1 & prophage == 1))
#[1] 241

#Quick check
377+348+228+241
#[1] 1194 #Looks good

#Now the question is: Of those hosts infected with prophages, how many were also infected by:

#Go back to the big data set to get all prophage infections to determine composition of single infections
#Need to conduct an **anti_join** to get rows **not matching** the coinfection data set, i.e. single infections
curated_single_infections <- anti_join(big_data_frame, curated_coinfections, by="Seq_ID")
View(curated_single_infections)

nrow(curated_single_infections)
#[1] 3728

nrow(curated_single_infections) + nrow(curated_coinfections_all) == nrow(big_data_frame)
#TRUE so I have the whole set
#12498

#Now need to get the proportion of single infections by extrachromosomal viruses vs. prophages
single_infection_type <- as.data.frame(table(curated_single_infections$Sequence.type, droplevels(curated_single_infections$Host)))
#droplevels important here for hosts, so I don't get all factors (hosts) listed in new data frame
View(single_infection_type)

#Adjust names
colnames(single_infection_type) <- c("Sequence_Type", "Host", "Viruses")

#Now have to cast to get tidy data set where each row is 1 host 
single_infection_type_cast <- dcast(single_infection_type, Host~Sequence_Type)
View(single_infection_type_cast)
#Looks good!

#Add total column to take care of potentially misassembeled genomes reported as separate viruses 
single_infection_type_cast <- mutate(single_infection_type_cast, total = extrachromosomal + prophage)
head(single_infection_type_cast)

colSums(single_infection_type_cast[2:4])
#extrachromosomal         prophage            total 
#           2105             1623             3728


#Apparent Coinfections: This command should yield 0, but quality control had  rejected as coinfections 
#because potentially misassembled Caudovirales
nrow(subset(single_infection_type_cast, total > 1))
#[1] 502

#Extrachromosomal-exclusive rejected coinfections
nrow(subset(single_infection_type_cast, total > 1 & prophage == 0))
#[1] 261

#Prophage exclusive rejected coinfections
nrow(subset(single_infection_type_cast, total > 1 & extrachromosomal == 0))
#[1] 42

#Prophage and extrachromosomal rejected coinfections
nrow(subset(single_infection_type_cast, prophage > 0 & extrachromosomal > 0))
#[1] 199
#These cases are interesting because they should be clearly coinfections since they invole a prophage
# and an extrachromosomal virus. However, they are probably both Caudovirales without multiple terminase (TerL) 
# genes and they are conservatively left as ambiguous. However, I can't cleanly assign them to single infections
# by prophages or extrachromosomal so I am dropping them from final calculations. Proportions calculated
# with or without them are similar, as shown below.

#Straightforward single infections
nrow(subset(single_infection_type_cast, total == 1))
#[1] 2545

#Of these:
nrow(subset(single_infection_type_cast, total == 1 & extrachromosomal == 1))
#[1] 1223 extrachromosomal and 
nrow(subset(single_infection_type_cast, total == 1 & prophage == 1))
#[1] 1322 prophage

#So Extrachromosomal single infections are:
nrow(subset(single_infection_type_cast, total == 1 & extrachromosomal == 1)) + nrow(subset(single_infection_type_cast, total > 1 & prophage == 0))
#[1] 1484

#Prophage single infections are:
nrow(subset(single_infection_type_cast, total == 1 & prophage == 1)) + nrow(subset(single_infection_type_cast, total > 1 & extrachromosomal == 0))
#[1] 1364

nrow(subset(single_infection_type_cast, prophage > 0 & extrachromosomal > 0))
#[1] 199 #And these 199 are ambiguous

#Total number of prophage infected hosts is
nrow(subset(single_infection_type_cast, total == 1 & prophage == 1)) + nrow(subset(single_infection_type_cast, total > 1 & extrachromosomal == 0)) +
  #prophage single infections
  nrow(subset(coinfection_infection_mode_cast, prophage > 0))
  #any coinfections with prophages
#[1] 3134

#OR, including the 199 ambiguous ones
3134 + nrow(subset(single_infection_type_cast, prophage > 0 & extrachromosomal > 0))
#[1] 3333

#Of all prophage infected hosts
nrow(subset(coinfection_infection_mode_cast, prophage > 0 & extrachromosomal > 0))
#1194
1194/3134
#[1] 0.3809828 had a coinfection with extrachromosomal
(1194+199)/(3134+199)
#[1] 0.4179418 #had infection with extrachromosomal, including ambiguous cases

#Compared to 
nrow(subset(coinfection_infection_mode_cast, prophage > 1 & extrachromosomal == 0))
#[1] 576
576/3134
#[1] 0.1837907 #that had infection with more prophages
576/(3134+199)
#[1] 0.1728173 #that had infection with more prophages, including ambiguous ones

#Compared to
nrow(subset(single_infection_type_cast, total == 1 & prophage == 1)) + nrow(subset(single_infection_type_cast, total > 1 & extrachromosomal == 0))
1364/3134
#[1] 0.4352265 #hosts that had with single prophage infections
1364/(3134+199)
#[1] 0.4092409 #hosts that had with single prophage infections, including ambiguous ones

#Again, going forward not including ambiguous ones, as they don't seem to make a big difference

#Verifying that each piece sums up to the total
576+1364+1194
#[1] 3134

#Are the number of hosts in coinfection statistically distinguishable from the number in single infections?
#Number of coinfections (out of n=3134) is 576+1194 = 1770, Number of single infections = 1364 
binom.test(1770, 3134)
#Exact binomial test
#data:  1770 and 3134
#number of successes = 1770, number of trials = 3134, p-value = 4.344e-13
#alternative hypothesis: true probability of success is not equal to 0.5
#95 percent confidence interval:
#  0.5472024 0.5822234
#sample estimates:
#  probability of success 
#0.5647735 

#Among coinfected prophages
576+1194
#[1] 1770

prop.test(c(576, 1194), c(1770, 1770))
#2-sample test for equality of proportions with continuity correction
#data:  c(576, 1194) out of c(1770, 1770)
#X-squared = 430.1571, df = 1, p-value < 2.2e-16
#alternative hypothesis: two.sided
#95 percent confidence interval:
#  -0.3805861 -0.3177190
#sample estimates:
#  prop 1    prop 2 
#0.3254237 0.6745763

binom.test(576, 1770)
#Exact binomial test
#data:  576 and 1770
#number of successes = 576, number of trials = 1770, p-value < 2.2e-16
#alternative hypothesis: true probability of success is not equal to 0.5
#95 percent confidence interval:
#  0.3036182 0.3478094
#sample estimates:
#  probability of success 
#0.3254237

#Figure 4A: Number of prophage-infected host cultures that were single infectios or coinfections
#Check out data
head(single_infection_type_cast)
head(coinfection_infection_mode_cast) 

#Will merge these data frames in a second, so need to prepare
coinfected <- NULL
coinfected <- rep("Co-infected", nrow(coinfection_infection_mode_cast))
all_cultures_coinfection <- cbind(coinfection_infection_mode_cast, coinfected)
head(all_cultures_coinfection)

#Create a label for composition of single infections
single_infection_type_cast$composition <- ifelse(single_infection_type_cast$extrachromosomal == 0 & single_infection_type_cast$prophage > 0, "Prophage Only", 
                                                      ifelse(single_infection_type_cast$extrachromosomal > 0 & single_infection_type_cast$prophage == 0, "Extrachromosomal Only", "Unknown"))
#Check
nrow(subset(single_infection_type_cast, composition == "Prophage Only"))
#[1] 1364 #Looks good
nrow(subset(single_infection_type_cast, composition == "Extrachromosomal Only"))
#[1] 1484 #Looks good
nrow(subset(single_infection_type_cast, composition == "Unknown"))
#[1] 199 #These are the ambiguous ones mentioned above

#Check if they now have same structure
head(single_infection_type_cast)
head(all_cultures_coinfection) 

#Need to add 'coinfected' column to single infections
coinfected <- NULL
coinfected <- rep("Single Infections", nrow(single_infection_type_cast))
single_infection_type_cast <- cbind(single_infection_type_cast, coinfected)
head(single_infection_type_cast)

#Join both data frames
all_cultures_coinfection <- rbind(all_cultures_coinfection, single_infection_type_cast)
nrow(all_cultures_coinfection)
#[1] 5492 #every host accounted for

#Now Plot Figure 4A: Are prophage-infected host cultures more likely to be single infections or coinfections?
#Note I subsetted out all the ambiguous single infections (199 hosts)
fig4a <- ggplot(subset(all_cultures_coinfection, composition != "Unknown" & prophage > 0), aes(x = coinfected, fill= coinfected)) +
  geom_bar(aes(y = (..count..)/sum(..count..)), col = "black") +
  scale_y_continuous(breaks=seq(0, 0.8, by=0.1)) +
  ylab("Proportion prophage-infected hosts") +
  xlab("") +
  theme(axis.title.y = element_text(angle=90, face="plain"), axis.title.x = element_text(face="plain", size = rel(1.4)), panel.background = element_rect(fill = 'grey90')) +
  scale_fill_manual(values = c("dodgerblue3","darkgrey")) +
  theme(legend.position = "none")

#View plot
fig4a

ggsave("figures/figure4a.pdf")

#Now Plot Figure 4B Plot: Are cultures with more than one prophage more likely 
# than cultures with prophages and extrachromosomal viruses

#requires package ggthemes
fig4B <- ggplot(subset(coinfection_infection_mode_cast, prophage > 0), aes(x = composition, fill = composition)) +
  geom_bar(aes(y = (..count..)/sum(..count..)), col = "black") +
  scale_y_continuous(breaks=seq(0, 0.8, by=0.1)) +
  ylab("Proportion prophage-infected hosts") +
  xlab("") +
  scale_fill_manual(values = c("dodgerblue3","dodgerblue3")) +
  theme(legend.position = "none")

#View Plot
fig4B


#Bring all main plots together 
grid.arrange(fig4a, fig4B, fig4C, nrow = 3)

#### 4. Sources explaining variation in the level of of culture coinfection   ####

#This section requires the metadata file that was imported in section 1 with this line of code
#culture_coinfection_gold_metadata <- read.csv("data/culture_coinfection_gold_metadata.csv")
View(culture_coinfection_gold_metadata)

#NEED to first remove duplicate rows
nrow(culture_coinfection_gold_metadata)
#[1] 5661

#Looks good. Missed a few from the 5492, prob. due to mismatches in the GOLD database?
nrow(culture_coinfection_gold_metadata[!duplicated(culture_coinfection_gold_metadata[,1]), ])
#[1] 5488

culture_coinfection_gold_metadata <- culture_coinfection_gold_metadata[!duplicated(culture_coinfection_gold_metadata[,1]), ]

nrow(culture_coinfection_gold_metadata)
#[1] 5488

#Need to fix trophy to just two levels to match potential coinfection data (Flores et al.)
#Using which() to subset 

#Mixotrophy is easy
culture_coinfection_gold_metadata[which(culture_coinfection_gold_metadata$ENERGY_SOURCE == "Mixotroph" | culture_coinfection_gold_metadata$ENERGY_SOURCE ==  "Heterotroph, Photosynthetic"), "ENERGY_SOURCE"] <- "Mixotroph"

#Building the query for autotrophs, which are in multiple categories
length(which(culture_coinfection_gold_metadata$ENERGY_SOURCE == "Autotroph" | culture_coinfection_gold_metadata$ENERGY_SOURCE ==  "Diazotroph, Photoautotroph" | 
        culture_coinfection_gold_metadata$ENERGY_SOURCE == "Lithoautotroph" | culture_coinfection_gold_metadata$ENERGY_SOURCE == "Photosynthetic" |
        culture_coinfection_gold_metadata$ENERGY_SOURCE == "Chemolithoautotroph" | culture_coinfection_gold_metadata$ENERGY_SOURCE == "Photoautotroph" |
        culture_coinfection_gold_metadata$ENERGY_SOURCE == "Photolithoautotroph" | culture_coinfection_gold_metadata$ENERGY_SOURCE == "Chemolithoautotrophic"))
#[1] 30
#Check if autotroph categories add up to 30 (confirmed "by hand")
with(culture_coinfection_gold_metadata, tapply(Grand.Total, ENERGY_SOURCE, length))
#yep

#Now implement query for autotrophs
culture_coinfection_gold_metadata[which(culture_coinfection_gold_metadata$ENERGY_SOURCE == "Autotroph" | culture_coinfection_gold_metadata$ENERGY_SOURCE ==  "Diazotroph, Photoautotroph" | 
                                          culture_coinfection_gold_metadata$ENERGY_SOURCE == "Lithoautotroph" | culture_coinfection_gold_metadata$ENERGY_SOURCE == "Photosynthetic" |
                                          culture_coinfection_gold_metadata$ENERGY_SOURCE == "Chemolithoautotroph" | culture_coinfection_gold_metadata$ENERGY_SOURCE == "Photoautotroph" |
                                          culture_coinfection_gold_metadata$ENERGY_SOURCE == "Photolithoautotroph" | culture_coinfection_gold_metadata$ENERGY_SOURCE == "Chemolithoautotrophic"), "ENERGY_SOURCE"] <- "Autotroph"
#Check
with(culture_coinfection_gold_metadata, tapply(Grand.Total, ENERGY_SOURCE, length))
#Autotrophs are 30, so worked

#Now label heterotrophs, i.e. everyone else. First check lengths
length(which(culture_coinfection_gold_metadata$ENERGY_SOURCE != "Autotroph" & culture_coinfection_gold_metadata$ENERGY_SOURCE !=  "Mixotroph"))
#[1] 5382

sum(with(culture_coinfection_gold_metadata, unname(tapply(Grand.Total, ENERGY_SOURCE, length))), na.rm = T) -
length(which(culture_coinfection_gold_metadata$ENERGY_SOURCE != "Autotroph" & culture_coinfection_gold_metadata$ENERGY_SOURCE !=  "Mixotroph"))
#[1] 33
#Which is the number of Autotrophs + Mixotrophs so good 

#Now assign heterotrophs
culture_coinfection_gold_metadata[which(culture_coinfection_gold_metadata$ENERGY_SOURCE != "Autotroph" & culture_coinfection_gold_metadata$ENERGY_SOURCE !=  "Mixotroph"), "ENERGY_SOURCE"] <- "Heterotroph"

#Check
with(culture_coinfection_gold_metadata, tapply(Grand.Total, ENERGY_SOURCE, length))

#Wait, let's clean up unused factors
culture_coinfection_gold_metadata$ENERGY_SOURCE <- factor(culture_coinfection_gold_metadata$ENERGY_SOURCE)

#Check again
with(culture_coinfection_gold_metadata, tapply(Grand.Total, ENERGY_SOURCE, length))
#ahhh...

#Need to remove rows with NA's in variables because if not step() will give errors when evaluating models
which(is.na(culture_coinfection_gold_metadata$ENERGY_SOURCE))
#quite a few
which(is.na(culture_coinfection_gold_metadata$ECOSYSTEM))
#A LOT
which(is.na(culture_coinfection_gold_metadata$ECOSYSTEM_TYPE))
#thousands
which(is.na(culture_coinfection_gold_metadata$Fam))
#all there
which(is.na(culture_coinfection_gold_metadata$Gen))
#all there
which(is.na(culture_coinfection_gold_metadata$Phyl))
#all there
which(is.na(culture_coinfection_gold_metadata$prophage))
#all there
which(is.na(culture_coinfection_gold_metadata$extrachromosomal))
#all there

#Make new data frame that doesn't contain NA's in the tested factors
#For ENERGY_SOURCE first
culture_coinfection_gold_metadata_full <- culture_coinfection_gold_metadata[-which(is.na(culture_coinfection_gold_metadata$ENERGY_SOURCE)), ]
#Now for ECOSYTEM
culture_coinfection_gold_metadata_full <- culture_coinfection_gold_metadata_full[-which(is.na(culture_coinfection_gold_metadata$ECOSYSTEM)), ]

#Add ssDNA_presence as a factor I will test in models
culture_coinfection_gold_metadata_full <- mutate(culture_coinfection_gold_metadata_full, ssDNA_pres = ssDNA > 0)

#Start tests

#First need to decide which taxonomic rank to test
#Which taxonomic rank?
m_culture2 <- glm(extrachromosomal ~ Phyl, family=poisson, data = culture_coinfection_gold_metadata_full)
m_culture3 <- glm(extrachromosomal ~ Fam, family=poisson, data = culture_coinfection_gold_metadata_full)
m_culture <- glm(extrachromosomal ~ ECOSYSTEM + ENERGY_SOURCE + Gen + prophage, family=poisson, data = culture_coinfection_gold_metadata_full)
m_culture4 <- glm(extrachromosomal ~ Gen, family=poisson, data = culture_coinfection_gold_metadata_full)
anova(m_culture2, m_culture3, m_culture4, test="Chisq")
#Analysis of Deviance Table
#Model 1: extrachromosomal ~ Phyl
#Model 2: extrachromosomal ~ Fam
#Model 3: extrachromosomal ~ Gen
#Resid. Df Resid. Dev  Df Deviance  Pr(>Chi)    
#1      5149     8666.7                           
#2      5041     7789.7 108   876.98 < 2.2e-16 ***
#3      4857     7212.7 184   576.99 < 2.2e-16 ***
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

#Genus works best

#Now first model. Poisson becase counts

m_culture <- glm(extrachromosomal ~ ECOSYSTEM + ENERGY_SOURCE + Gen + ssDNA_pres + prophage, family=poisson, data = culture_coinfection_gold_metadata_full)
summary(m_culture)

step(m_culture)
#step() selects extrachromosomal ~ ECOSYSTEM + Gen + prophage, therefore, ENERGY_SOURCE and ssDNA_pres dropped

drop1(m_culture, test = "Chisq")
#Single term deletions
#Model:extrachromosomal ~ ECOSYSTEM + ENERGY_SOURCE + Gen + ssDNA_pres + prophage
#               Df Deviance   AIC     LRT Pr(>Chi)    
#<none>              6661.4 15363                     
#ECOSYSTEM       2   6670.4 15368    9.02  0.01098 *  
#ENERGY_SOURCE   2   6662.4 15360    0.95  0.62105    
#Gen           308   8406.6 16492 1745.16  < 2e-16 ***
#ssDNA_pres      1   6662.3 15362    0.84  0.36001    
#prophage        1   6933.2 15633  271.78  < 2e-16 ***
#  ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

library(AER)
dispersiontest(m_culture, alternative="two.sided") #Can reject null hypothesis that dispersion is 1
#Overdispersion stat sig, but not large 1.462059... how to proceed? neg binomial or quasipoisson or zeroinf

#Let's try a negative binomial

library(MASS)
m_culture_nb <- glm.nb(extrachromosomal ~ ECOSYSTEM + Gen + prophage, data = culture_coinfection_gold_metadata_full)

library(pscl)
odTest(m_culture_nb) #Poisson is rejected for negative binomial 
#Likelihood ratio test of H0: Poisson, as restricted NB model:
#  n.b., the distribution of the test-statistic under H0 is non-standard
#e.g., see help(odTest) for details/references
#Critical value of test statistic at the alpha= 0.05 level: 2.7055 
#Chi-Square Test Statistic =  253.4902 p-value = < 2.2e-16 

source("dsquared.R")
Dsquared(m_culture_nb)

#Let's try zero-inflated poisson
m_culture_zinf <- zeroinfl(extrachromosomal ~ ECOSYSTEM + Gen + prophage | 1, data = culture_coinfection_gold_metadata_full)
#Doable, but not sure what parameters should be used to estimate occurence of zeros. Here using fixed probability, but results
# similar using other variables

#Is standard negative binomial better than zeroinflated poisson?
vuong(m_culture_zinf, m_culture_nb) #For sure
#Vuong Non-Nested Hypothesis Test-Statistic: 
#  (test-statistic is asymptotically distributed N(0,1) under the
#   null that the models are indistinguishible)
#
#  Vuong z-statistic             H_A  p-value
#Raw                   -2.232959 model2 > model1 0.012776
#AIC-corrected         -2.149053 model2 > model1 0.015815
#BIC-corrected         -1.875528 model2 > model1 0.030360

#Of all alternative models (poisson, zero-inflated poisson, negative binomial, and zero-inflated negative binomial)
# the standard negative bionomial performs better as judged by AIC

m_culture <- glm.nb(extrachromosomal ~ ECOSYSTEM + Gen + prophage, data = culture_coinfection_gold_metadata_full)
Dsquared(m_culture)

#Visual fit check
plot(culture_coinfection_gold_metadata_full$extrachromosomal)
points(fitted(m_culture), col=2)

#More information on model estimates for each parameter

summary(m_culture)
as.data.frame(exp(coef(m_culture)))
as.data.frame(coef(m_culture))

#subset(summary(m_culture)$coef, "Pr(>|z|)" < 0.05)

m_culture_sig_coef <- data.frame(summary(m_culture)$coef[summary(m_culture)$coef[,4] <= .05, ])
colnames(m_culture_sig_coef) <- c("Coef", "Std_Error", "z.value", "p")
m_culture_sig_coef <- cbind(m_culture_sig_coef, Exp_Coef = exp(m_culture_sig_coef$Coef))
m_culture_sig_coef

m_culture_ranked_coef <- as.data.frame(coef(m_culture))
m_culture_ranked_coef <- cbind(Row.Names = rownames(m_culture_ranked_coef), m_culture_ranked_coef)
rownames(m_culture_ranked_coef) <- NULL
colnames(m_culture_ranked_coef) <- c("Variable", "Coef")
m_culture_ranked_coef <- mutate(m_culture_ranked_coef, Exp_Coef = exp(Coef))
#sort by incident rate (exponentiated coeficient)
m_culture_ranked_coef <- m_culture_ranked_coef[order(-m_culture_ranked_coef$Exp_Coef), ]
m_culture_ranked_coef

#Summary Stats for Genus
genus_extrachromosomal <- as.data.frame(with(culture_coinfection_gold_metadata_full, tapply(extrachromosomal, Gen, mean)))
genus_extrachromosomal <- cbind(Row.Names = rownames(genus_extrachromosomal), genus_extrachromosomal)
rownames(genus_extrachromosomal) <- NULL
colnames(genus_extrachromosomal) <- c("Genus", "Mean")
genus_extrachromosomal <- cbind(genus_extrachromosomal, with(culture_coinfection_gold_metadata_full, as.vector(tapply(extrachromosomal, Gen, sd))))
colnames(genus_extrachromosomal) <- c("Genus", "Mean", "SD")
genus_extrachromosomal <- cbind(genus_extrachromosomal, with(culture_coinfection_gold_metadata_full, as.vector(tapply(extrachromosomal, Gen, length))))
colnames(genus_extrachromosomal) <- c("Genus", "Mean", "SD", "N")
genus_extrachromosomal <- genus_extrachromosomal[order(-genus_extrachromosomal$Mean), ]

#Remove anything with a sample size of less than 1 and 
genus_extrachromosomal <- subset(genus_extrachromosomal, N > 1 & N != "NA")
genus_extrachromosomal$Genus <- factor(genus_extrachromosomal$Genus)
genus_extrachromosomal

#Summary Stats for Ecosystem
with(culture_coinfection_gold_metadata_full, tapply(extrachromosomal, ECOSYSTEM, mean))
with(culture_coinfection_gold_metadata_full, tapply(extrachromosomal, ECOSYSTEM, sd))
with(culture_coinfection_gold_metadata_full, tapply(extrachromosomal, ECOSYSTEM, length))

#Figures

#Ecosystems
g_cult1 <- ggplot(aes(ECOSYSTEM, extrachromosomal), data=subset(culture_coinfection_gold_metadata_full, ECOSYSTEM != "NA")) + theme(legend.position="none") + 
  geom_point(aes(colour=ECOSYSTEM), position=position_jitter(width=0.3, height=0.25), alpha=0.25) + scale_y_continuous(breaks=seq(0, 20, 1)) +
  geom_errorbar(stat = "hline", yintercept = "mean", size=0.8, aes(ymax=..y..,ymin=..y..)) + coord_flip() +
  xlab("Ecosystem") + ylab("Extrachromosomal viruses infecting")

#Summary Stats

#Energy Source
g_cult2 <- ggplot(aes(ENERGY_SOURCE, extrachromosomal), data=subset(culture_coinfection_gold_metadata_full, ENERGY_SOURCE != "NA")) + theme(legend.position="none") + 
  geom_point(aes(colour=ENERGY_SOURCE), position=position_jitter(width=0.3, height=0.25), alpha=0.65) + scale_y_continuous(breaks=seq(0, 20, 1)) +
  geom_errorbar(stat = "hline", yintercept = "mean", size=0.8, width=0.8, aes(ymax=..y..,ymin=..y..)) + coord_flip() +
  xlab("Host energy source") + ylab("Extrachromosomal viruses infecting")

#Summary Stats

#Prophage
g_cult3 <- ggplot(aes(prophage, extrachromosomal), data=subset(culture_coinfection_gold_metadata_full, prophage != "NA")) + theme(legend.position="none") + 
  geom_point(aes(colour=prophage), position=position_jitter(width=0.3, height=0.25), alpha=0.65) + scale_y_continuous(breaks=seq(0, 20, 1)) +
  xlab("Number of prophages in host") + ylab("Extrachromosomal viruses infecting")

#ssDNA Presence/Absence
g_cult4 <- ggplot(aes(ssDNA_pres, extrachromosomal), data=subset(culture_coinfection_gold_metadata_full, ssDNA_pres != "NA")) + theme(legend.position="none") + 
  geom_point(aes(colour=ssDNA_pres), position=position_jitter(width=0.3, height=0.25), alpha=0.65) + scale_y_continuous(breaks=seq(0, 20, 1)) +
  geom_errorbar(stat = "hline", yintercept = "mean", size=0.8, width=0.8, aes(ymax=..y..,ymin=..y..)) + coord_flip() +
  xlab("ssDNA virus infecting?") + ylab("Extrachromosomal viruses infecting")

#Genus
g_cult5 <- ggplot(aes(reorder(Genus, Mean), Mean), data=subset(genus_extrachromosomal, Mean > 0)) +
  geom_point(aes(colour=Genus)) + coord_flip() +  
  theme_classic() + theme(legend.position="none", panel.border = element_rect(colour = "black", fill=NA, size=1), axis.text.y = element_text(size=5), axis.ticks.y=element_blank()) +
  xlab("Genus") + ylab("Mean extrachromosomal viruses infecting")

#Bring plots together
#Requires package GridExtra

culture_rtable <- tableGrob(round(m_culture_sig_coef, digits=2))
grid.arrange(culture_rtable)

#Figure S3
grid.arrange(g_cult5, arrangeGrob(g_cult1, g_cult2, g_cult3, g_cult4, nrow=4), ncol=2)

#Table S3
grid.arrange(culture_rtable)

#Figure 2
grid.arrange(g_cult5, arrangeGrob(g_cult1, g_cult3, nrow=4), ncol=2)
