################ Single cell coinfection analyses
#### 1. Data Sources and Preparing Data
#### 2. Descriptive statistics of single-cell coinfections
#### 3. Test whether cells with CRISPR spacers or putative defective prophages decrease coinfection
#### 4. Sources explaining variation in the level Single Cell Coinfections
#### 5. Generate Figures

#Load libraries
library(ggplot2)
library(plyr)
library(reshape2)
library(gridExtra)
library(dplyr) #not using yet
library(ggthemes)
library(sandwich)
#Load standard error function
source("sem.R")

#Analyzing data from Roux et al. 2014. Reference:
#Roux, S., Hawley, A. K., Torres Beltran, M., Scofield, M., Schwientek, P., Stepanauskas, R., et al. (2014). Ecology and evolution of viruses infecting uncultivated SUP05 bacteria as revealed by single-cell- and meta- genomics. eLife, 3. doi:10.7554/eLife.03125
#Supplementary file 4: supplementary-file-4.media-6.xls
#located at http://dx.doi.org/10.7554/eLife.03125.024

#### 1. Data Sources and Preparing Data ####

#Description of file from Roux et al. 2014:
#"List of viral sequences detected for each SUP05 SAGs with at least one viral contig or defective prophage. 
#For the detection of viral contigs, full-length contigs are indicated by a cross (x), 
#partial matches (short contigs matching the full-length sequence) are noted with a dash (−).
#For the short contigs not similar to any SUP05 viral reference sequence, 
#the number of different contigs identified is indicated for each cell."

#Preprocessing of file included replacing 'x' and '-' dashes for 1. Double dashes are marked as one infection,
#as they represent matches to a single phage genome.
#Otherwise, file imported as is and renamed: roux_et_al_2014_infection_data_past_present.csv

#Import
roux_et_al_2014 <- read.csv("data/roux_et_al_2014_infection_data_past_present.csv", na.strings="", stringsAsFactors=FALSE)

#Change NA's to zeros
roux_et_al_2014[is.na(roux_et_al_2014)] <- 0
View(roux_et_al_2014)
#NOTE there are two empty columns in the original spredsheet, which R renames X and X.1. We'll leave them
# in because they shouldn't interfere with anything downstream

#Calculate the sum of viral infections (contigs)
#Subset to include only the infection rows
roux_et_al_2014[,4:14]
#same as subset:
#subset(roux_et_al_2014, select = c(Microviridae,  Podoviridae.M8F6_0,	Podoviridae.C22_13,	Siphoviridae.G10_6,	Podoviridae.K04_0,	Other.short.contig,	X,	Putative.viral.contig.s.,	X.1, CRISPR, Defective.prophage))

#Just checking
View(roux_et_al_2014[,4:14])

#Sum
total <- rowSums(roux_et_al_2014[,4:14])

#Add sum of infections to data frame
roux_et_al_2014 <- cbind(roux_et_al_2014, total)
mean(roux_et_al_2014$total)

#Calculate sum only of current infections
roux_et_al_2014[,4:12]
#same as subset:
#subset(roux_et_al_2014, select = c(Microviridae,  Podoviridae.M8F6_0,  Podoviridae.C22_13,	Siphoviridae.G10_6,	Podoviridae.K04_0,	Other.short.contig,	X,	Putative.viral.contig.s., X.1))

#Sum
total_current <- rowSums(roux_et_al_2014[,4:12])

#Add sum of only current infections to data frame
roux_et_al_2014 <- cbind(roux_et_al_2014, total_current)
mean(roux_et_al_2014$total_current)

#Past viral infections
roux_et_al_2014[,13:14]
#same as subset:
#subset(roux_et_al_2014, select = c(CRISPR, Defective.prophage))

#Sum
total_past <- rowSums(roux_et_al_2014[,13:14])
#Add sum of only past infections to data frame
roux_et_al_2014 <- cbind(roux_et_al_2014, total_past)
mean(roux_et_al_2014$total_past)
#[1] 0.5671642
sd(roux_et_al_2014$total_past)
#[1] 0.6086219

#### 2. Descriptive statistics of single-cell coinfections ####
#Generate some summary stats for single and multiple infections in SAGs

colnames(roux_et_al_2014)[1:3] <- c("SAG.Id", "Cluster", "Depth")

#Generate some summary stats for single and multiple infections in SAGs
multiple_current <- (subset(total_current, total_current > 1))
length(multiple_current)
#[1] 19
single_current <- (subset(total_current, total_current == 1))
length(single_current)
#[1] 23
length(total_current)
#[1] 67
single_total <- (subset(total, total == 1))
length(single_total)
#[1] 42
multiple_total <- (subset(total, total > 1))
length(multiple_total)
#[1] 25
multiple_past <- (subset(total_past, total_past > 1))
length(multiple_past)
#[1] 4
single_past <- (subset(total_past, total_past == 1))
length(single_past)
#[1] 30

single_multiple_infections <- data.frame(
  time = factor(c("Total", "Total", "Current", "Current", "Past", "Past")), levels=c("Total", "Current", "Past"),
  infection_type = factor(c("Single Infections", "Multiple Infections", "Single Infections", "Multiple Infections", "Single Infections", "Multiple Infections"),  levels=c("Single Infections", "Multiple Infections")),
  infections = c(length(single_total), length(multiple_total), length(single_current), length(multiple_current), length(single_past), length(multiple_past)),
  color = factor(c("single", "multiple_total", "single", "multiple_current", "single", "multiple_past"))
  )

#Number of Single and Multiple Infections in Single Amplified Genomes
p2 <- ggplot(single_multiple_infections, aes(x=infection_type, y=infections, fill=color)) +
  geom_bar(stat = "identity") + facet_grid(. ~ time) + xlab("Viral Infections") + 
  scale_fill_manual(values = c("red", "green","blue", "grey")) +
  ylab("Number of Single Amplified Genomes of Bacteria") +
  theme(legend.position = "none")

#Plot that will illustrate how many viruses are involved in these multiple infections
mean(multiple_total)
#[1] 2.56
mean(multiple_current)
#[1] 2.368421
mean(multiple_past)
#[1] 2

#Preparation for summary data frame on the number of viruses infecting SAGs
time <- c("Current", "Past", "Total")
mean_viruses <- c(mean(multiple_current), mean(multiple_past), mean(multiple_total))  
sd_viruses <- c(sd(multiple_current), sd(multiple_past), sd(multiple_total))
min_viruses <- c(min(multiple_current), min(multiple_past), min(multiple_total))
max_viruses <- c(max(multiple_current), max(multiple_past), max(multiple_total))

#Create Summary Data Frame
number_infecting_sags <- data.frame(time, mean_viruses, sd_viruses, min_viruses, max_viruses)

#Plot circle plot showing min/average/max coinfection level
p1 <- ggplot(number_infecting_sags, aes(x = mean_viruses, fill = factor(time))) + geom_bar(width = 1) + 
  geom_bar(aes(x = max_viruses), alpha = I(0.5)) + 
  geom_bar(aes(x = min_viruses), alpha = I(0.5)) +
  coord_polar(theta = "y", start = 0) +
  scale_fill_manual(values = c("red", "green","blue")) +
  theme_bw() +
  theme(axis.text.x = element_blank(),
        panel.border = element_blank(),
        legend.position = "none",
        panel.margin = unit(2, "lines")
        ) +
  xlab("Viruses in multiple infections") +
  ylab("") +
  scale_x_discrete(breaks=seq(0, 5, 1)) +
  facet_wrap(~time)

ggplot(number_infecting_sags, aes(x = mean_viruses, fill = factor(time))) + geom_bar(width = 1) + 
  geom_bar(aes(x = max_viruses), alpha = I(0.5)) + 
  geom_bar(aes(x = min_viruses), alpha = I(0.5)) +
  coord_polar(theta = "y", start = 0) +
  scale_fill_manual(values = c("red", "green","blue")) +
  theme_bw() +
  theme(axis.text.x = element_blank(),
        panel.border = element_blank(),
        legend.position = "none",
        panel.margin = unit(2, "lines"),
        panel.grid.major = element_line(colour = "black")
        ) +
  xlab("Viruses in multiple infections") +
  ylab("") +
  scale_x_discrete(breaks=seq(0, 5, 1)) +
  facet_wrap(~time)

#Bring plots together. Requires package GridExtra
grid.arrange(p1, p2, nrow = 2)
#NOTE: All plots above are not included in manuscript, alternate summaries/visualizations of published data

#### 3. Test whether cells with CRISPR spacers or putative defective prophages decrease coinfection ####

#Proportion Test to examine whether the proportion of singly infected vs multiply infected bacteria is 
# statistically significantly different.
prop.test(c(23, 29), c(67, 67))

#2-sample test for equality of proportions with continuity correction
#data:  c(23, 29) out of c(67, 67)
#X-squared = 0.7856, df = 1, p-value = 0.3754
#alternative hypothesis: two.sided
#95 percent confidence interval:
#  -0.26879684  0.08969236
#sample estimates:
#  prop 1    prop 2 
#0.3432836 0.4328358 

#OK now let's do some plotting

ggplot(data=roux_et_al_2014, aes(x=SAG.Id, y=total)) + geom_point() + coord_flip()

ggplot(data=roux_et_al_2014, aes(x=SAG.Id, y=total)) + geom_bar(stat = "identity") + coord_flip()

#Melt the data set for some plotting DOUBLE CHECK INDEXING
sga_infections <- melt(roux_et_al_2014[15:17])
#Fix Column Names
colnames(sga_infections) <- c("infection_type", "infections")

ggplot(sga_infections, aes(x = infections)) + geom_histogram() + facet_grid(infection_type ~ .)

ggplot(sga_infections, aes(x = infections)) + geom_bar(stat = "identity") + facet_grid(infection_type ~ .)

#Effect of CRISPRs and Defective Prophages on Coinfection
#Do previous infections limit the scope for coinfection?

#CRISPRs
sum(roux_et_al_2014$CRISPR)
#[1] 25
current_CRISPR <- subset(roux_et_al_2014, CRISPR == 1, select = total_current, drop=TRUE)
sum(current_CRISPR)
#[1] 17

length(current_CRISPR)
#[1] 25
length(subset(current_CRISPR, current_CRISPR > 0))
#[1] 8


current_NO_CRISPR <- subset(roux_et_al_2014, CRISPR == 0, select = total_current, drop=TRUE)
sum(current_NO_CRISPR)
#[1] 51
length(current_NO_CRISPR)
#[1] 42

length(subset(current_NO_CRISPR, current_NO_CRISPR > 0))
#[1] 34


#check if length is correct
length(current_NO_CRISPR$total_current) + length(current_CRISPR$total_current) == 67

#Test on whether cells with CRISPRs are equally likely to have any current infection
prop.test(x = c(8, 34), n = c(25, 42))

#2-sample test for equality of proportions with continuity correction

#data:  c(8, 34) out of c(25, 42)
#X-squared = 14.0308, df = 1, p-value = 0.0001798
#alternative hypothesis: two.sided
#95 percent confidence interval:
#  -0.7394635 -0.2395841
#sample estimates:
#  prop 1    prop 2 
#0.3200000 0.8095238 

wilcox.test(current_CRISPR, current_NO_CRISPR, conf.int = TRUE)
#Wilcoxon rank sum test with continuity correction

#data:  current_CRISPR and current_NO_CRISPR
#W = 342, p-value = 0.01246
#alternative hypothesis: true location shift is not equal to 0
#95 percent confidence interval:
#  -1.000015e+00 -4.331725e-05
#sample estimates:
#  difference in location 
#-0.9999602 

#Warning messages:
#  1: In wilcox.test.default(current_CRISPR, current_NO_CRISPR, conf.int = TRUE) :
#  cannot compute exact p-value with ties
#2: In wilcox.test.default(current_CRISPR, current_NO_CRISPR, conf.int = TRUE) :
#  cannot compute exact confidence intervals with ties

mean(current_CRISPR)
#[1] 0.68
mean(current_NO_CRISPR)
#[1] 1.214286

#BUT Are CRISPR and Defective Prophages correlated?
# only 3 cells that have CRISPRs also have defective prophages and none of those have current infections
# double check down here using code.

subset(roux_et_al_2014, CRISPR > 0 & Defective.prophage > 0, select = total_current, drop=TRUE)
#[1] 0 0 0
#Yep!

#Defective Prophages
sum(roux_et_al_2014$Defective.prophage)
#[1] 13
current_prophage <- subset(roux_et_al_2014, Defective.prophage == 1, select = total_current, drop=TRUE)
sum(current_prophage)
#[1] 1

length(current_prophage)
#[1] 11

length(subset(current_prophage, current_prophage > 0))
#[1] 1

current_NO_prophage <- subset(roux_et_al_2014, Defective.prophage == 0, select = total_current, drop=TRUE)
sum(current_NO_prophage)
#[1] 67

length(current_NO_prophage)
#[1] 55

length(subset(current_NO_prophage, current_NO_prophage > 0))
#[1] 41

#Test on whether cells with prophages are equally likely to have any current infection
prop.test(x = c(1, 41), n = c(11, 55))
#2-sample test for equality of proportions with continuity correction

#data:  c(1, 41) out of c(11, 55)
#X-squared = 14.2607, df = 1, p-value = 0.0001592
#alternative hypothesis: two.sided
#95 percent confidence interval:
#  -0.9143094 -0.3947815
#sample estimates:
#  prop 1     prop 2 
#0.09090909 0.74545455 

#Warning message:
#  In prop.test(x = c(1, 41), n = c(11, 55)) :
#  Chi-squared approximation may be incorrect

#Cells having defective prophages are 65.45% more likely not to have a current infection!!

#Test on whether the average number of current coinfecting phage is different
#normality check...
hist(current_prophage)
hist(current_NO_prophage)
#clearly non-normal

wilcox.test(current_prophage, current_NO_prophage, conf.int = TRUE)
#Wilcoxon rank sum test with continuity correction

#data:  current_prophage and current_NO_prophage
#W = 95, p-value = 0.000171
#alternative hypothesis: true location shift is not equal to 0
#95 percent confidence interval:
#  -1.9999697 -0.9999599
#sample estimates:
#  difference in location 
#-1.000024

#This figure has been dropped, but is instructive. Similar figures now included in Figure 3 in manuscript
#Need to group and label the cells with/without Prophages
View(subset(roux_et_al_2014, Defective.prophage  > 0))
#Make new data frame to edit
sags_prophage_crispr <- roux_et_al_2014
#Easier than subsetting :)
sags_prophage_crispr$prophage_presence <- ifelse(sags_prophage_crispr$Defective.prophage > 0,"Defective prophage present", "No defective prophages")
View(sags_prophage_crispr)

##Need to group and label the cells with/without CRISPR spacers
sags_prophage_crispr$crispr_presence <- ifelse(sags_prophage_crispr$CRISPR > 0,"CRISPR spacers present", "No CRISPR spacers")
View(sags_prophage_crispr)

#Now Plot, note: requires ggthemes
prophages <- ggplot(sags_prophage_crispr, aes(x = prophage_presence, y = total_current)) + 
  geom_point(aes(colour=as.factor(prophage_presence)), size = 4, alpha=0.75, position=position_jitter(width=0.2, height=0.1)) +
  ylab("Number of viruses actively infecting cell") +
  xlab("") +
  theme_gdocs() +
  scale_color_manual(values = c("darkorchid1","blue1")) +
  theme(legend.position="none", axis.title.y = element_text(angle=90, face = "plain"), panel.grid.major.x = element_blank(), panel.grid.major.y = element_blank())

crispr <- ggplot(sags_prophage_crispr, aes(x = crispr_presence, y = total_current)) + 
  geom_point(aes(colour=as.factor(crispr_presence)), size = 4, alpha=0.75, position=position_jitter(width=0.2, height=0.1)) +
  ylab("Number of viruses actively infecting cell") +
  xlab("") +
  theme_gdocs() +
  scale_color_manual(values = c("darkorchid1","blue1")) +
  theme(legend.position="none", axis.title.y = element_text(angle=90, face = "plain"), panel.grid.major.x = element_blank(), panel.grid.major.y = element_blank())


grid.arrange(prophages, crispr, nrow = 2)

ggsave(filename = "figures/figure4.pdf")


#### 4. Sources explaining variation in the level Single Cell Coinfections  ####

#Start with big data frame 
View(roux_et_al_2014)

#Rename first three rows for easier inclusion in the model
names(roux_et_al_2014)[1:3] <- c("SAG.Id", "Cluster", "Depth")
#These represent the ID, 16S phylogeny, and ecology through ocean depth

#"Best" starting point
m_single_cell <- glm(total_current ~ Cluster + Depth + CRISPR + Defective.prophage, family="poisson", data=roux_et_al_2014)
summary(m_single_cell)
plot(m_single_cell)

#Alternative looking at total coinfection, but can't use prophage or crispr, because included in total
m_single_cell <- glm(total ~ Cluster + Depth, family="poisson", data=roux_et_al_2014)
summary(m_single_cell)
#Yeah, terrible keep original

#Now let's go step by step 
m_single_cell <- glm(total_current ~ Cluster + Depth + CRISPR + Defective.prophage, family="poisson", data=roux_et_al_2014)
summary(m_single_cell)
plot(m_single_cell)

step(m_single_cell) #Cluster was dropped

#update model with step
m_single_cell <- step(m_single_cell)
summary(m_single_cell)
#Call:
#  glm(formula = total_current ~ Depth + CRISPR + Defective.prophage, 
#      family = "poisson", data = roux_et_al_2014)
#
#Deviance Residuals: 
#  Min       1Q   Median       3Q      Max  
#-1.3874  -0.8323  -0.1824  -0.0080   2.0153  

#Coefficients:
#  Estimate Std. Error z value Pr(>|z|)   
#  (Intercept)        -2.197696   1.094350  -2.008   0.0446 * 
#  Depth               0.015832   0.006452   2.454   0.0141 * 
#  CRISPR             -0.769514   0.282209  -2.727   0.0064 **
#  Defective.prophage -2.402484   1.007252  -2.385   0.0171 * 
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
#(Dispersion parameter for poisson family taken to be 1)
#Null deviance: 79.942  on 66  degrees of freedom
#Residual deviance: 47.208  on 63  degrees of freedom
#AIC: 153.14
#Number of Fisher Scoring iterations: 6

#Depth now significant. AIC down. Same Dsquared with one fewer variables

m_single_cell_ranked_coef <- as.data.frame(coef(m_single_cell))
m_single_cell_ranked_coef <- cbind(Row.Names = rownames(m_single_cell_ranked_coef), m_single_cell_ranked_coef)
rownames(m_single_cell_ranked_coef) <- NULL
colnames(m_single_cell_ranked_coef) <- c("Variable", "Coef")
m_single_cell_ranked_coef <- mutate(m_single_cell_ranked_coef, Exp_Coef = exp(Coef))
#sort by incident rate (exponentiated coeficient)
m_single_cell_ranked_coef <- m_single_cell_ranked_coef[order(-m_single_cell_ranked_coef$Exp_Coef), ]
m_single_cell_ranked_coef


#Using robust standard errors for parameter estimates
cov <- vcovHC(m_single_cell, type="HC0")
std.err <- sqrt(diag(cov))
r.est <- cbind(Estimate= coef(m_single_cell), "Robust SE" = std.err,
               "Pr(>|z|)" = 2 * pnorm(abs(coef(m_single_cell)/std.err), lower.tail=FALSE),
               LL = coef(m_single_cell) - 1.96 * std.err,
               UL = coef(m_single_cell) + 1.96 * std.err)

r.est
#                   Estimate   Robust SE    Pr(>|z|)           LL          UL
#(Intercept)        -2.19769631 0.818683514 0.007265420 -3.802316000 -0.59307663
#Depth               0.01583168 0.004881967 0.001183238  0.006263027  0.02540034
#CRISPR             -0.76951398 0.280963490 0.006165641 -1.320202425 -0.21882554
#Defective.prophage -2.40248415 0.940223980 0.010611907 -4.245323152 -0.55964515

#Check if ressiduals are normal
hist(residuals(m_single_cell))
#Normal-ish and median close to 0 (-0.1824)

#Is goodness of fit test significant?
with(m_single_cell, cbind(res.deviance = deviance, df = df.residual,
                          p = pchisq(deviance, df.residual, lower.tail=FALSE)))
#     res.deviance df         p
#[1,]     47.20842 63 0.9311602
#Not significant, so model fits reasonably well

#Check the influence of each one of the terms. Are they significant?
drop1(m_single_cell, test = "Chisq")
#Single term deletions
#Model:
#  total_current ~ Depth + CRISPR + Defective.prophage
#                      Df Deviance    AIC     LRT  Pr(>Chi)    
#<none>                    47.208 153.14                      
#  Depth               1   53.693 157.63  6.4844 0.0108828 *  
#  CRISPR              1   55.487 159.42  8.2785 0.0040117 ** 
#  Defective.prophage  1   61.161 165.10 13.9526 0.0001875 ***
#  ---
#  Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

#So in factors are in order of increasing importance up to Defective.prophage. Dropping it results in a
# ((61.161-47.208)/47.208)*100= 29.55643% increase in deviance

#Check fitted values
plot(roux_et_al_2014$Defective.prophage, roux_et_al_2014$total_current)
points(roux_et_al_2014$Defective.prophage, fitted(m_single_cell), col=2)
plot(roux_et_al_2014$CRISPR, roux_et_al_2014$total_current)
points(roux_et_al_2014$CRISPR, fitted(m_single_cell), col=3)
plot(roux_et_al_2014$Depth, roux_et_al_2014$total_current)
points(roux_et_al_2014$Depth, fitted(m_single_cell), col=4)
#Looks pretty good!

#Now check for overdispersion
#Residual deviance/DF should be 1, because Poisson mean == variance
47.208 / 63
#[1] 0.7493333

#Let's check if our dispersion is different from 1
library(AER)
dispersiontest(m_single_cell, alternative="two.sided") #Cannot reject that true dispersion is 1 
#Dispersion test
#data:  m_single_cell
#z = -1.6959, p-value = 0.0899
#alternative hypothesis: true dispersion is not equal to 1
#sample estimates:
#  dispersion 
#0.8168751

plot(roux_et_al_2014$total_current)
points(fitted(m_single_cell), col=2)
#Pretty good!

#Present results as incident rate ratios with SE's 
library(msm)

z <- deltamethod(list(~ exp(x1), ~ exp(x2), ~ exp(x3), ~ exp(x4)), coef(m_single_cell), cov)
rexp.est <- exp(r.est[, -3])
rexp.est[, "Robust SE"] <- z
rexp.est

#                   Estimate   Robust SE         LL        UL
#(Intercept)        0.11105871 0.090921934 0.02231902 0.5526244
#Depth              1.01595767 0.004959872 1.00628268 1.0257257
#CRISPR             0.46323815 0.130153009 0.26708123 0.8034619
#Defective.prophage 0.09049288 0.085083572 0.01433110 0.5714118

rexp.est <- as.data.frame(cbind(rexp.est, p = as.data.frame(r.est)$"Pr(>|z|)"))
colnames(rexp.est) <- c("Exp_Coef", "Robust SE", "LL", "UL", "p") 

#Now some summary stats by variabes
with(roux_et_al_2014, tapply(total_current, Depth, mean))
with(roux_et_al_2014, tapply(total_current, Depth, sd))
with(roux_et_al_2014, tapply(total_current, Depth, length))

with(roux_et_al_2014, tapply(total_current, CRISPR, mean))
with(roux_et_al_2014, tapply(total_current, CRISPR, sd))
with(roux_et_al_2014, tapply(total_current, CRISPR, length))

with(roux_et_al_2014, tapply(total_current, Defective.prophage, mean))
with(roux_et_al_2014, tapply(total_current, Defective.prophage, sd))
with(roux_et_al_2014, tapply(total_current, Defective.prophage, length))

#Cluster was NS in final model, but here are summary stats
with(roux_et_al_2014, tapply(total_current, Cluster, mean))
with(roux_et_al_2014, tapply(total_current, Cluster, sd))
with(roux_et_al_2014, tapply(total_current, Cluster, length))

#### 5. Generate Figures  ####
#Make graphs 
#Depth first
g_sing1 <- ggplot(roux_et_al_2014, aes(x = as.factor(Depth), y = total_current)) + 
  geom_point(aes(colour=as.factor(Depth)), size = 4, alpha=0.80, position=position_jitter(width=0.2, height=0.1)) +
  ylab("Number of viruses actively infecting cell") +
  xlab("Ocean depth (m)") +
  theme_gdocs() +
  scale_color_manual(values = c("aquamarine2","aquamarine3", "aquamarine4")) +
  theme(legend.position="none", axis.title.y = element_text(angle=90, face = "plain"), panel.grid.major.x = element_blank(), panel.grid.major.y = element_blank(), plot.background = element_rect(colour = "black", size = 0))

#Cluster 
g_sing2 <- ggplot(roux_et_al_2014, aes(x = Cluster, y = total_current)) + 
  geom_point(aes(colour=Cluster), size = 4, alpha=0.75, position=position_jitter(width=0.2, height=0.1)) +
  scale_colour_brewer(palette = "Set1") +
  ylab("Number of viruses actively infecting cell") +
  xlab("small subunit rRNA Cluster") +
  theme_gdocs() +
  theme(legend.position="none", axis.title.y = element_text(angle=90, face = "plain"), panel.grid.major.x = element_blank(), panel.grid.major.y = element_blank(), plot.background = element_rect(colour = "black", size = 0))

#Prophages
g_sing3 <- ggplot(roux_et_al_2014, aes(x = as.factor(Defective.prophage), y = total_current)) + 
  geom_point(aes(colour=as.factor(Defective.prophage)), size = 4, alpha=0.75, position=position_jitter(width=0.2, height=0.1)) +
  ylab("Number of viruses actively infecting cell") +
  xlab("Number of putative defective prophages") +
  theme_gdocs() +
  scale_color_manual(values = c("blue1","blue1", "blue1")) +
  theme(legend.position="none", axis.title.y = element_text(angle=90, face = "plain"), panel.grid.major.x = element_blank(), panel.grid.major.y = element_blank(), plot.background = element_rect(colour = "black", size = 0))

#CRISPR
g_sing4 <- ggplot(roux_et_al_2014, aes(x = as.factor(CRISPR), y = total_current)) + 
  geom_point(aes(colour=as.factor(CRISPR)), size = 4, alpha=0.75, position=position_jitter(width=0.2, height=0.1)) +
  ylab("Number of viruses actively infecting cell") +
  xlab("CRISPR spacers") +
  theme_gdocs() +
  scale_color_manual(values = c("darkorchid1","darkorchid1")) +
  theme(legend.position="none", axis.title.y = element_text(angle=90, face = "plain"), panel.grid.major.x = element_blank(), panel.grid.major.y = element_blank(), plot.background = element_rect(colour = "black", size = 0))

#Bring graphs together
#Requires package GridExtra
#Figure S4
grid.arrange(g_sing1, g_sing2, g_sing3, g_sing4)

#Figure 3
single_rtable <- tableGrob(round(rexp.est, digits=3))
grid.arrange(single_rtable)

#All together
grid.arrange(g_sing1, g_sing3, g_sing4, arrangeGrob(single_rtable))